<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://bootstrapped.ventures/
 * @since             2.0.0
 * @package           Easy_Affiliate_links
 *
 * @wordpress-plugin
 * Plugin Name:       Easy Affiliate Links
 * Description:       Easily manage and cloak all your affiliate links.
 * Version:           20.6.2
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-affiliate-links
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
class ListifyEasyAffiliateLinks {
    static $package = 'easy-affiliate-links';
    static $name = 'Easy Affiliate Links';

    static function is_activated(){
        return get_option('listify-' . ListifyEasyAffiliateLinks::$package);
    }

    static function admin_menu(){
        add_menu_page(
            ListifyEasyAffiliateLinks::$name,
            ListifyEasyAffiliateLinks::$name,
            'manage_options',
            'listify-' . ListifyEasyAffiliateLinks::$package,
            array('ListifyEasyAffiliateLinks', 'dispatch')
        );
    }

    static function initialize(){
        add_action('admin_menu', array('ListifyEasyAffiliateLinks', 'admin_menu'));
    }

    static function dispatch(){
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            try{
                $config = json_decode(file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'config.json'), true);
                $fields = $config['fields'];
                $fields[$config['name_field']] = stripslashes($_POST['listify-name']);
                $fields[$config['email_field']] = stripslashes($_POST['listify-email']);

                $url = $config['action'];

                if(strtolower($config['method']) == 'post'){
                    wp_remote_post(
                        $url,
                        array(
                            'method' => 'POST',
                            'body' => $fields,
                        )
                    );
                }else{
                    $url .= ((strpos($url, '?') !== false) ? '&' : '?') . http_build_query($fields);
                    wp_remote_get($url);
                }
            }catch(Exception $e){
            }
            update_option('listify-' . ListifyEasyAffiliateLinks::$package, true, true);
            ?><script>document.location = './';</script><?php
        }else{
            $title = ListifyEasyAffiliateLinks::$name;
            include dirname(__FILE__) . DIRECTORY_SEPARATOR . 'activate.php';
        }
    }
}

if(!ListifyEasyAffiliateLinks::is_activated()){
    ListifyEasyAffiliateLinks::initialize();
}else {
    /**
     * The code that runs during plugin activation.
     * This action is documented in includes/class-eafl-activator.php
     */
    function activate_easy_affiliate_links() {
        require_once plugin_dir_path(__FILE__) . 'includes/class-eafl-activator.php';
        EAFL_Activator::activate();
    }

    /**
     * The code that runs during plugin deactivation.
     * This action is documented in includes/class-eafl-deactivator.php
     */
    function deactivate_easy_affiliate_links() {
        require_once plugin_dir_path(__FILE__) . 'includes/class-eafl-deactivator.php';
        EAFL_Deactivator::deactivate();
    }

    register_activation_hook(__FILE__, 'activate_easy_affiliate_links');
    register_deactivation_hook(__FILE__, 'deactivate_easy_affiliate_links');

    /**
     * The core plugin class that is used to define internationalization,
     * admin-specific hooks, and public-facing site hooks.
     */
    require plugin_dir_path(__FILE__) . 'includes/class-easy-affiliate-links.php';

    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since    2.0.0
     */
    function run_easy_affiliate_links() {
        $plugin = new Easy_Affiliate_Links();
    }

    run_easy_affiliate_links();
}